/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
const defaultTreeConfigurationOptions = {
    enableSchemaValidation: false,
};
/**
 * Configuration for how to {@link ITree.schematize | schematize} a tree.
 * @public
 */
export class TreeConfiguration {
    schema;
    initialTree;
    /**
     * Additional options that can be specified when {@link ITree.schematize | schematizing } a tree.
     */
    options;
    /**
     * @param schema - The schema which the application wants to view the tree with.
     * @param initialTree - A function that returns the default tree content to initialize the tree with iff the tree is uninitialized
     * (meaning it does not even have any schema set at all).
     * If `initialTree` returns any actual node instances, they should be recreated each time `initialTree` runs.
     * This is because if the config is used a second time any nodes that were not recreated could error since nodes cannot be inserted into the tree multiple times.
     * @param options - Additional options that can be specified when {@link ITree.schematize | schematizing } a tree.
     */
    constructor(schema, initialTree, options) {
        this.schema = schema;
        this.initialTree = initialTree;
        this.options = { ...defaultTreeConfigurationOptions, ...options };
    }
}
//# sourceMappingURL=tree.js.map